//
//  GMNetService.h
//  Pods
//
//  Created by wangyang on 16/5/13.
//
//

#import <Foundation/Foundation.h>
#import "GMNetConstant.h"

/**
 *  @brief  针对业务的封装
 */
@class WMNetworking, WMNetSecurityWorking;

@interface GMNetService : NSObject

/**
 *  @author licong, 15-11-19 19:11:02
 *
 *  初始化时候,下载器时候必须设置好,分别用来HTTP和HTTPS请求,但不负责有关上传的HTTP/HTTPS请求,上传图片用了单独的AFHTTPSessionManager
 *
 *  @since 0.2.3
 */
/***  @brief  普通HTTP下载器*/
@property (nonatomic, strong) WMNetworking *networking;
/***  @brief  稍安全HTTPS下载器*/
@property (nonatomic, strong) WMNetSecurityWorking *netSecurityworking;
/***  @brief  普通HTTP HOST*/
@property (nonatomic, strong) NSString *apiHost;
/***  @brief  稍安全HTTPS HOST*/
@property (nonatomic, strong) NSString *apiSecurityHost;

@property (nonatomic, strong) NSString *webHost;
@property (nonatomic, strong) NSString *loginExpiredName;
@property (nonatomic, strong) NSString *urlCommonParameters;

+ (GMNetService *)sharedInstance;

/**
 *  @author wangyang, 16-05-12 17:05:14
 *
 *  只适用于新业务
 */
- (void)sendRequestWithUrl:(NSString *)urlString
                parameters:(nullable id)parameters
                    method:(HttpMethod)method
                   success:(nullable ResultData)success
                    failed:(nullable ResultFailed)failed;

- (void)sendSecurityRequestWithUrl:(NSString *)urlString
                        parameters:(nullable id)parameters
                            method:(HttpMethod)method
                           success:(nullable ResultData)success
                            failed:(nullable ResultFailed)failed;

/**
 *  @author licong, 15-11-19 12:11:55
 *
 *  @brief  普通HTTP上传图片,API_HOST是http://开头
 *
 *  @param data      文件大小
 *  @param fileName  文件名,不能为空,服务器没指定,直接填充@"file"
 *  @param name      关联上传数据的名字，不能为空,服务器没指定,直接填充@"file"
 *  @param url       上传地址
 *  @param mineType  文件类型。image/jpg、audio/aac
 *
 *  @since 0.2.2
 */
- (void)sendUploadTaskRequestWithData:(NSData *)data
                             fileName:(NSString *)fileName
                                 name:(NSString*)name
                                  url:(NSString*)url
                             mineType:(NSString *)mineType
                           parameters:(NSDictionary *)parameters
                              success:(HttpSuccessBlock)success
                               failed:(HttpFailedBlock)failed;

/**
 *  @brief  HTTPS安全上传请求，API_HOST是https://开头
 */
- (void)sendSecurityUploadTaskRequestWithData:(NSData *)data
                                     fileName:(NSString *)fileName
                                         name:(NSString*)name
                                          url:(NSString*)url
                                     mineType:(NSString *)mineType
                                   parameters:(NSDictionary *)parameters
                                      success:(HttpSuccessBlock)success
                                       failed:(HttpFailedBlock)failed;

#pragma clang diagnostic pop


@end
